@@ -22,16 +22,22 @@ from __future__ import annotations
 
 import logging
 
+from typing import TYPE_CHECKING
+
 import click
 
 from molecule import scenarios
 from molecule.command import base
 
 
+if TYPE_CHECKING:
+    from molecule.types import CommandArgs, MoleculeArgs
+
+
 LOG = logging.getLogger(__name__)
 
 
-class Matrix(base.Base):  # pylint: disable=abstract-method
+class Matrix(base.Base):
     """Matrix Command Class.
 
     .. program:: molecule matrix subcommand
@@ -73,10 +79,21 @@ class Matrix(base.Base):  # pylint: disable=abstract-method
 # NOTE(retr0h): Cannot introspect base.Base for `click.Choice`, since
 # subclasses have not all loaded at this point.
 @click.argument("subcommand", nargs=1, type=click.UNPROCESSED)
-def matrix(ctx, scenario_name, subcommand):  # type: ignore[no-untyped-def] # pragma: no cover  # noqa: ANN001, ANN201
-    """List matrix of steps used to test instances."""
-    args = ctx.obj.get("args")
-    command_args = {"subcommand": subcommand}
+def matrix(
+    ctx: click.Context,
+    scenario_name: str,
+    subcommand: str,
+) -> None:  # pragma: no cover
+    """List matrix of steps used to test instances.
 
-    s = scenarios.Scenarios(base.get_configs(args, command_args), scenario_name)
+    Args:
+        ctx: Click context object holding commandline arguments.
+        scenario_name: Name of the scenario to target.
+        subcommand: Subcommand to target.
+    """
+    args: MoleculeArgs = ctx.obj.get("args")
+    command_args: CommandArgs = {"subcommand": subcommand}
+
+    scenario_names = [] if scenario_name is None else [scenario_name]
+    s = scenarios.Scenarios(base.get_configs(args, command_args), scenario_names)
     s.print_matrix()
